@@ -19,31 +19,32 @@ Usage::
     ```
 """
 from datetime import datetime
-from typing import Iterator
+from typing import Iterator, Union
 
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .literals import SortOrderType
-from .type_defs import ListHumanLoopsResponseTypeDef, PaginatorConfigTypeDef
+from .type_defs import ListHumanLoopsResponseResponseTypeDef, PaginatorConfigTypeDef
 
 __all__ = ("ListHumanLoopsPaginator",)
 
 
 class ListHumanLoopsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/paginators.html#listhumanloopspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/paginators.html#listhumanloopspaginator)
     """
 
     def paginate(
         self,
         *,
         FlowDefinitionArn: str,
-        CreationTimeAfter: datetime = None,
-        CreationTimeBefore: datetime = None,
+        CreationTimeAfter: Union[datetime, str] = None,
+        CreationTimeBefore: Union[datetime, str] = None,
         SortOrder: SortOrderType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListHumanLoopsResponseTypeDef]:
+    ) -> Iterator[ListHumanLoopsResponseResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/paginators.html#listhumanloopspaginator)
         """
